/****************************************************************************
** Meta object code from reading C++ file 'sieveeditorpagewidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../pim-sieve-editor-26.07.90/src/sieveeditorpagewidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sieveeditorpagewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21SieveEditorPageWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto SieveEditorPageWidget::qt_create_metaobjectdata<qt_meta_tag_ZN21SieveEditorPageWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SieveEditorPageWidget",
        "refreshList",
        "",
        "scriptModified",
        "SieveEditorPageWidget*",
        "modeEditorChanged",
        "KSieveUi::SieveEditorWidget::EditorMode",
        "undoAvailable",
        "redoAvailable",
        "copyAvailable",
        "sieveEditorTabCurrentChanged",
        "requestCloseTab",
        "index"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'refreshList'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scriptModified'
        QtMocHelpers::SignalData<void(bool, SieveEditorPageWidget *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'modeEditorChanged'
        QtMocHelpers::SignalData<void(KSieveUi::SieveEditorWidget::EditorMode)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'undoAvailable'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'redoAvailable'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'copyAvailable'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'sieveEditorTabCurrentChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestCloseTab'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SieveEditorPageWidget, qt_meta_tag_ZN21SieveEditorPageWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SieveEditorPageWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SieveEditorPageWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SieveEditorPageWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21SieveEditorPageWidgetE_t>.metaTypes,
    nullptr
} };

void SieveEditorPageWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SieveEditorPageWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refreshList(); break;
        case 1: _t->scriptModified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SieveEditorPageWidget*>>(_a[2]))); break;
        case 2: _t->modeEditorChanged((*reinterpret_cast<std::add_pointer_t<KSieveUi::SieveEditorWidget::EditorMode>>(_a[1]))); break;
        case 3: _t->undoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->redoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->copyAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->sieveEditorTabCurrentChanged(); break;
        case 7: _t->requestCloseTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SieveEditorPageWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SieveEditorPageWidget::*)()>(_a, &SieveEditorPageWidget::refreshList, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorPageWidget::*)(bool , SieveEditorPageWidget * )>(_a, &SieveEditorPageWidget::scriptModified, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorPageWidget::*)(KSieveUi::SieveEditorWidget::EditorMode )>(_a, &SieveEditorPageWidget::modeEditorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorPageWidget::*)(bool )>(_a, &SieveEditorPageWidget::undoAvailable, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorPageWidget::*)(bool )>(_a, &SieveEditorPageWidget::redoAvailable, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorPageWidget::*)(bool )>(_a, &SieveEditorPageWidget::copyAvailable, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorPageWidget::*)()>(_a, &SieveEditorPageWidget::sieveEditorTabCurrentChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorPageWidget::*)(int )>(_a, &SieveEditorPageWidget::requestCloseTab, 7))
            return;
    }
}

const QMetaObject *SieveEditorPageWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SieveEditorPageWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SieveEditorPageWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int SieveEditorPageWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void SieveEditorPageWidget::refreshList()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SieveEditorPageWidget::scriptModified(bool _t1, SieveEditorPageWidget * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void SieveEditorPageWidget::modeEditorChanged(KSieveUi::SieveEditorWidget::EditorMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SieveEditorPageWidget::undoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SieveEditorPageWidget::redoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void SieveEditorPageWidget::copyAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void SieveEditorPageWidget::sieveEditorTabCurrentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SieveEditorPageWidget::requestCloseTab(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
