/********************************************************************************
** Form generated from reading UI file 'serversievesettings.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SERVERSIEVESETTINGS_H
#define UI_SERVERSIEVESETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpasswordlineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ServerSieveSettings
{
public:
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidget;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *serverName;
    QLabel *label_2;
    QLineEdit *userName;
    QLabel *label_4;
    KPasswordLineEdit *password;
    QLabel *serversievelabel;
    QLabel *label_3;
    QSpinBox *port;
    QLabel *label_5;
    QComboBox *authenticationCombo;
    QWidget *tab_4;
    QVBoxLayout *verticalLayout_4;
    QLabel *label_11;
    QGroupBox *safeImap;
    QVBoxLayout *verticalLayout_3;
    QPushButton *testButton;
    QFormLayout *formLayout_2;
    QLabel *label_12;
    QHBoxLayout *horizontalLayout;
    QRadioButton *noRadio;
    QRadioButton *sslRadio;
    QRadioButton *tlsRadio;
    QLabel *label_13;
    QSpinBox *imapPort;
    QLabel *label_14;
    QComboBox *imapAuthenticationCombo;
    QGroupBox *alternateServer;
    QGridLayout *gridLayout;
    QLabel *label_7;
    QLineEdit *imapServerName;
    QLabel *label_6;
    QLineEdit *imapUserName;
    QLabel *label_8;
    KPasswordLineEdit *imapPassword;
    QLabel *testInfo;
    QProgressBar *testProgress;
    QSpacerItem *verticalSpacer;
    QButtonGroup *safeImapGroup;

    void setupUi(QWidget *ServerSieveSettings)
    {
        if (ServerSieveSettings->objectName().isEmpty())
            ServerSieveSettings->setObjectName("ServerSieveSettings");
        ServerSieveSettings->resize(515, 510);
        verticalLayout_2 = new QVBoxLayout(ServerSieveSettings);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(ServerSieveSettings);
        tabWidget->setObjectName("tabWidget");
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        verticalLayout = new QVBoxLayout(tab_3);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(tab_3);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        serverName = new QLineEdit(tab_3);
        serverName->setObjectName("serverName");
        serverName->setClearButtonEnabled(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, serverName);

        label_2 = new QLabel(tab_3);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        userName = new QLineEdit(tab_3);
        userName->setObjectName("userName");
        userName->setClearButtonEnabled(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, userName);

        label_4 = new QLabel(tab_3);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_4);

        password = new KPasswordLineEdit(tab_3);
        password->setObjectName("password");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, password);

        serversievelabel = new QLabel(tab_3);
        serversievelabel->setObjectName("serversievelabel");
        serversievelabel->setWordWrap(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, serversievelabel);

        label_3 = new QLabel(tab_3);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_3);

        port = new QSpinBox(tab_3);
        port->setObjectName("port");
        port->setMinimum(1);
        port->setMaximum(65536);
        port->setValue(4190);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, port);

        label_5 = new QLabel(tab_3);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_5);

        authenticationCombo = new QComboBox(tab_3);
        authenticationCombo->setObjectName("authenticationCombo");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, authenticationCombo);


        verticalLayout->addLayout(formLayout);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        verticalLayout_4 = new QVBoxLayout(tab_4);
        verticalLayout_4->setObjectName("verticalLayout_4");
        label_11 = new QLabel(tab_4);
        label_11->setObjectName("label_11");

        verticalLayout_4->addWidget(label_11);

        safeImap = new QGroupBox(tab_4);
        safeImap->setObjectName("safeImap");
        safeImap->setCheckable(true);
        safeImap->setChecked(false);
        verticalLayout_3 = new QVBoxLayout(safeImap);
        verticalLayout_3->setObjectName("verticalLayout_3");
        testButton = new QPushButton(safeImap);
        testButton->setObjectName("testButton");

        verticalLayout_3->addWidget(testButton);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_12 = new QLabel(safeImap);
        label_12->setObjectName("label_12");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_12);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        noRadio = new QRadioButton(safeImap);
        safeImapGroup = new QButtonGroup(ServerSieveSettings);
        safeImapGroup->setObjectName("safeImapGroup");
        safeImapGroup->addButton(noRadio);
        noRadio->setObjectName("noRadio");
        noRadio->setChecked(true);

        horizontalLayout->addWidget(noRadio);

        sslRadio = new QRadioButton(safeImap);
        safeImapGroup->addButton(sslRadio);
        sslRadio->setObjectName("sslRadio");

        horizontalLayout->addWidget(sslRadio);

        tlsRadio = new QRadioButton(safeImap);
        safeImapGroup->addButton(tlsRadio);
        tlsRadio->setObjectName("tlsRadio");

        horizontalLayout->addWidget(tlsRadio);


        formLayout_2->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_13 = new QLabel(safeImap);
        label_13->setObjectName("label_13");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_13);

        imapPort = new QSpinBox(safeImap);
        imapPort->setObjectName("imapPort");
        imapPort->setMinimum(1);
        imapPort->setMaximum(65534);
        imapPort->setValue(143);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, imapPort);

        label_14 = new QLabel(safeImap);
        label_14->setObjectName("label_14");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_14);

        imapAuthenticationCombo = new QComboBox(safeImap);
        imapAuthenticationCombo->addItem(QString());
        imapAuthenticationCombo->addItem(QString());
        imapAuthenticationCombo->addItem(QString());
        imapAuthenticationCombo->addItem(QString());
        imapAuthenticationCombo->addItem(QString());
        imapAuthenticationCombo->addItem(QString());
        imapAuthenticationCombo->addItem(QString());
        imapAuthenticationCombo->addItem(QString());
        imapAuthenticationCombo->setObjectName("imapAuthenticationCombo");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, imapAuthenticationCombo);


        verticalLayout_3->addLayout(formLayout_2);


        verticalLayout_4->addWidget(safeImap);

        alternateServer = new QGroupBox(tab_4);
        alternateServer->setObjectName("alternateServer");
        alternateServer->setCheckable(true);
        alternateServer->setChecked(false);
        gridLayout = new QGridLayout(alternateServer);
        gridLayout->setObjectName("gridLayout");
        label_7 = new QLabel(alternateServer);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_7, 0, 0, 1, 1);

        imapServerName = new QLineEdit(alternateServer);
        imapServerName->setObjectName("imapServerName");
        imapServerName->setClearButtonEnabled(true);

        gridLayout->addWidget(imapServerName, 0, 1, 1, 1);

        label_6 = new QLabel(alternateServer);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_6, 1, 0, 1, 1);

        imapUserName = new QLineEdit(alternateServer);
        imapUserName->setObjectName("imapUserName");
        imapUserName->setClearButtonEnabled(true);

        gridLayout->addWidget(imapUserName, 1, 1, 1, 1);

        label_8 = new QLabel(alternateServer);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_8, 2, 0, 1, 1);

        imapPassword = new KPasswordLineEdit(alternateServer);
        imapPassword->setObjectName("imapPassword");

        gridLayout->addWidget(imapPassword, 2, 1, 1, 1);


        verticalLayout_4->addWidget(alternateServer);

        testInfo = new QLabel(tab_4);
        testInfo->setObjectName("testInfo");
        QFont font;
        font.setBold(true);
        testInfo->setFont(font);
        testInfo->setAlignment(Qt::AlignCenter);
        testInfo->setWordWrap(true);

        verticalLayout_4->addWidget(testInfo);

        testProgress = new QProgressBar(tab_4);
        testProgress->setObjectName("testProgress");
        testProgress->setValue(24);

        verticalLayout_4->addWidget(testProgress);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        tabWidget->addTab(tab_4, QString());

        verticalLayout_2->addWidget(tabWidget);

        QWidget::setTabOrder(serverName, userName);
        QWidget::setTabOrder(userName, password);
        QWidget::setTabOrder(password, port);
        QWidget::setTabOrder(port, authenticationCombo);

        retranslateUi(ServerSieveSettings);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ServerSieveSettings);
    } // setupUi

    void retranslateUi(QWidget *ServerSieveSettings)
    {
        label->setText(tr2i18n("Server Name:", nullptr));
        label_2->setText(tr2i18n("Username:", nullptr));
        label_4->setText(tr2i18n("Password:", nullptr));
        serversievelabel->setText(tr2i18n("The server port changed when ManageSieve turned into a full RFC Standard. Old server implementations still use port 2000, while newer standard conform server can only be accessed via port 4190.", nullptr));
        label_3->setText(tr2i18n("Port:", nullptr));
        label_5->setText(tr2i18n("Authentication:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Sieve Settings", nullptr));
        label_11->setText(tr2i18n("IMAP settings is necessary if you want to be able to list folders from server.", nullptr));
#if QT_CONFIG(whatsthis)
        safeImap->setWhatsThis(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'HandelGotDLig'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-weight:600;\">SSL/TLS</span><span style=\" font-family:'Sans Serif';\"> is safe IMAP over port 993;</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-weight:600;\">STARTTLS</span><span style=\" font-family:'Sans Serif';\"> will operate on port 143 and switch to a secure connection directly after connecting;</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0p"
                        "x; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-weight:600;\">None</span><span style=\" font-family:'Sans Serif';\"> will connect to port 143 but not switch to a secure connection. This setting is not recommended.</span></p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        safeImap->setTitle(tr2i18n("Connection Settings", nullptr));
        testButton->setText(tr2i18n("Auto Detect", nullptr));
        label_12->setText(tr2i18n("Encryption:", nullptr));
        noRadio->setText(tr2i18n("None", nullptr));
        sslRadio->setText(tr2i18n("SSL/TLS", nullptr));
        tlsRadio->setText(tr2i18n("STARTTLS", nullptr));
        label_13->setText(tr2i18n("Port:", nullptr));
        label_14->setText(tr2i18n("Authentication:", nullptr));
        imapAuthenticationCombo->setItemText(0, tr2i18n("Clear text", "Authentication method"));
        imapAuthenticationCombo->setItemText(1, tr2i18n("LOGIN", "Authentication method"));
        imapAuthenticationCombo->setItemText(2, tr2i18n("PLAIN", "Authentication method"));
        imapAuthenticationCombo->setItemText(3, tr2i18n("CRAM-MD5", "Authentication method"));
        imapAuthenticationCombo->setItemText(4, tr2i18n("DIGEST-MD5", "Authentication method"));
        imapAuthenticationCombo->setItemText(5, tr2i18n("NTLM", "Authentication method"));
        imapAuthenticationCombo->setItemText(6, tr2i18n("GSSAPI", "Authentication method"));
        imapAuthenticationCombo->setItemText(7, tr2i18n("Anonymous", "Authentication method"));

        alternateServer->setTitle(tr2i18n("Alternate Server", nullptr));
        label_7->setText(tr2i18n("Server Name:", nullptr));
        label_6->setText(tr2i18n("Username:", nullptr));
        label_8->setText(tr2i18n("Password:", nullptr));
        testInfo->setText(tr2i18n("Empty", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), tr2i18n("IMAP Settings", nullptr));
        (void)ServerSieveSettings;
    } // retranslateUi

};

namespace Ui {
    class ServerSieveSettings: public Ui_ServerSieveSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SERVERSIEVESETTINGS_H

