/****************************************************************************
** Meta object code from reading C++ file 'sieveeditorscriptmanagerwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../pim-sieve-editor-26.07.90/src/sieveeditorscriptmanagerwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sieveeditorscriptmanagerwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30SieveEditorScriptManagerWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto SieveEditorScriptManagerWidget::qt_create_metaobjectdata<qt_meta_tag_ZN30SieveEditorScriptManagerWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SieveEditorScriptManagerWidget",
        "createScriptPage",
        "",
        "KSieveUi::ManageSieveWidget::ScriptInfo",
        "info",
        "isNewScript",
        "updateButtons",
        "newScriptAction",
        "editScriptAction",
        "deleteScriptAction",
        "desactivateScriptAction",
        "scriptDeleted",
        "QUrl",
        "url",
        "serverSieveFound",
        "hasServerSieve",
        "scriptRenamed",
        "oldUrl",
        "newUrl",
        "slotCreateNewScript",
        "slotDeleteScript",
        "slotRefreshList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'createScriptPage'
        QtMocHelpers::SignalData<void(const KSieveUi::ManageSieveWidget::ScriptInfo &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'updateButtons'
        QtMocHelpers::SignalData<void(bool, bool, bool, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 }, { QMetaType::Bool, 8 }, { QMetaType::Bool, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Signal 'scriptDeleted'
        QtMocHelpers::SignalData<void(const QUrl &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'serverSieveFound'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'scriptRenamed'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 17 }, { 0x80000000 | 12, 18 },
        }}),
        // Slot 'slotCreateNewScript'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeleteScript'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRefreshList'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SieveEditorScriptManagerWidget, qt_meta_tag_ZN30SieveEditorScriptManagerWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SieveEditorScriptManagerWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30SieveEditorScriptManagerWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30SieveEditorScriptManagerWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30SieveEditorScriptManagerWidgetE_t>.metaTypes,
    nullptr
} };

void SieveEditorScriptManagerWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SieveEditorScriptManagerWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createScriptPage((*reinterpret_cast<std::add_pointer_t<KSieveUi::ManageSieveWidget::ScriptInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->updateButtons((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 2: _t->scriptDeleted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->serverSieveFound((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->scriptRenamed((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 5: _t->slotCreateNewScript(); break;
        case 6: _t->slotDeleteScript(); break;
        case 7: _t->slotRefreshList(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SieveEditorScriptManagerWidget::*)(const KSieveUi::ManageSieveWidget::ScriptInfo & , bool )>(_a, &SieveEditorScriptManagerWidget::createScriptPage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorScriptManagerWidget::*)(bool , bool , bool , bool )>(_a, &SieveEditorScriptManagerWidget::updateButtons, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorScriptManagerWidget::*)(const QUrl & )>(_a, &SieveEditorScriptManagerWidget::scriptDeleted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorScriptManagerWidget::*)(bool )>(_a, &SieveEditorScriptManagerWidget::serverSieveFound, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorScriptManagerWidget::*)(const QUrl & , const QUrl & )>(_a, &SieveEditorScriptManagerWidget::scriptRenamed, 4))
            return;
    }
}

const QMetaObject *SieveEditorScriptManagerWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SieveEditorScriptManagerWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30SieveEditorScriptManagerWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int SieveEditorScriptManagerWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void SieveEditorScriptManagerWidget::createScriptPage(const KSieveUi::ManageSieveWidget::ScriptInfo & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void SieveEditorScriptManagerWidget::updateButtons(bool _t1, bool _t2, bool _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void SieveEditorScriptManagerWidget::scriptDeleted(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SieveEditorScriptManagerWidget::serverSieveFound(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SieveEditorScriptManagerWidget::scriptRenamed(const QUrl & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
