// This file is generated by kconfig_compiler_kf6 from sieveeditorglobalconfig.kcfg.
// All changes you do to this file will be lost.
#ifndef SIEVEEDITORGLOBALCONFIG_H
#define SIEVEEDITORGLOBALCONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class SieveEditorGlobalConfig : public KConfigSkeleton
{
  public:

    static SieveEditorGlobalConfig *self();
    ~SieveEditorGlobalConfig() override;

    /**
      Set WrapText
    */
    static
    void setWrapText( bool v )
    {
      if (!self()->isWrapTextImmutable())
        self()->mWrapText = v;
    }

    /**
      Get WrapText
    */
    static
    bool wrapText()
    {
      return self()->mWrapText;
    }

    /**
      Is WrapText Immutable
    */
    static
    bool isWrapTextImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WrapText" ) );
    }

    /**
      Get Item object corresponding to WrapText()
    */
    ItemBool *wrapTextItem()
    {
      return mWrapTextItem;
    }

    /**
      Set PreviousNewFeaturesMD5
    */
    static
    void setPreviousNewFeaturesMD5( const QString & v )
    {
      if (!self()->isPreviousNewFeaturesMD5Immutable())
        self()->mPreviousNewFeaturesMD5 = v;
    }

    /**
      Get PreviousNewFeaturesMD5
    */
    static
    QString previousNewFeaturesMD5()
    {
      return self()->mPreviousNewFeaturesMD5;
    }

    /**
      Is PreviousNewFeaturesMD5 Immutable
    */
    static
    bool isPreviousNewFeaturesMD5Immutable()
    {
      return self()->isImmutable( QStringLiteral( "PreviousNewFeaturesMD5" ) );
    }

    /**
      Get Item object corresponding to PreviousNewFeaturesMD5()
    */
    ItemString *previousNewFeaturesMD5Item()
    {
      return mPreviousNewFeaturesMD5Item;
    }

    /**
      Set ShowMenuBar
    */
    static
    void setShowMenuBar( bool v )
    {
      if (!self()->isShowMenuBarImmutable())
        self()->mShowMenuBar = v;
    }

    /**
      Get ShowMenuBar
    */
    static
    bool showMenuBar()
    {
      return self()->mShowMenuBar;
    }

    /**
      Is ShowMenuBar Immutable
    */
    static
    bool isShowMenuBarImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ShowMenuBar" ) );
    }

    /**
      Get Item object corresponding to ShowMenuBar()
    */
    ItemBool *showMenuBarItem()
    {
      return mShowMenuBarItem;
    }

  protected:
    SieveEditorGlobalConfig();
    friend class SieveEditorGlobalConfigHelper;


    // Editor
    bool mWrapText;

    // General
    QString mPreviousNewFeaturesMD5;

    // Views
    bool mShowMenuBar;

  private:
    ItemBool *mWrapTextItem;
    ItemString *mPreviousNewFeaturesMD5Item;
    ItemBool *mShowMenuBarItem;
};

#endif

