/****************************************************************************
** Meta object code from reading C++ file 'sieveeditormainwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../pim-sieve-editor-26.07.90/src/sieveeditormainwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sieveeditormainwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21SieveEditorMainWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto SieveEditorMainWidget::qt_create_metaobjectdata<qt_meta_tag_ZN21SieveEditorMainWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SieveEditorMainWidget",
        "updateButtons",
        "",
        "newScriptAction",
        "editScriptAction",
        "deleteScriptAction",
        "desactivateScriptAction",
        "updateScriptList",
        "modeEditorChanged",
        "KSieveUi::SieveEditorWidget::EditorMode",
        "serverSieveFound",
        "undoAvailable",
        "redoAvailable",
        "copyAvailable",
        "sieveEditorTabCurrentChanged",
        "slotDebugSieveScript",
        "slotGoToLine",
        "slotReplace",
        "slotFind",
        "slotCopy",
        "slotPaste",
        "slotCut",
        "slotSaveAs",
        "slotCheckSpelling",
        "slotImport",
        "slotCreateRulesGraphically",
        "slotCheckSyntax",
        "slotComment",
        "slotUncomment",
        "slotUpperCase",
        "slotSentenceCase",
        "slotLowerCase",
        "slotReverseCase",
        "slotZoomIn",
        "slotZoomOut",
        "slotZoomReset",
        "slotWordWrap",
        "slotPrintPreview",
        "slotPrint",
        "slotUndo",
        "slotRedo",
        "slotSelectAll"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'updateButtons'
        QtMocHelpers::SignalData<void(bool, bool, bool, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { QMetaType::Bool, 4 }, { QMetaType::Bool, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'updateScriptList'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeEditorChanged'
        QtMocHelpers::SignalData<void(KSieveUi::SieveEditorWidget::EditorMode)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'serverSieveFound'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'undoAvailable'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'redoAvailable'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'copyAvailable'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'sieveEditorTabCurrentChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDebugSieveScript'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoToLine'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotReplace'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFind'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopy'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPaste'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCut'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveAs'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCheckSpelling'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotImport'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCreateRulesGraphically'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCheckSyntax'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotComment'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUncomment'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpperCase'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSentenceCase'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLowerCase'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotReverseCase'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomIn'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomOut'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomReset'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWordWrap'
        QtMocHelpers::SlotData<void(bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotPrintPreview'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPrint'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUndo'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRedo'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectAll'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SieveEditorMainWidget, qt_meta_tag_ZN21SieveEditorMainWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SieveEditorMainWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QSplitter::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SieveEditorMainWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SieveEditorMainWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21SieveEditorMainWidgetE_t>.metaTypes,
    nullptr
} };

void SieveEditorMainWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SieveEditorMainWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateButtons((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 1: _t->updateScriptList(); break;
        case 2: _t->modeEditorChanged((*reinterpret_cast<std::add_pointer_t<KSieveUi::SieveEditorWidget::EditorMode>>(_a[1]))); break;
        case 3: _t->serverSieveFound((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->undoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->redoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->copyAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->sieveEditorTabCurrentChanged(); break;
        case 8: _t->slotDebugSieveScript(); break;
        case 9: _t->slotGoToLine(); break;
        case 10: _t->slotReplace(); break;
        case 11: _t->slotFind(); break;
        case 12: _t->slotCopy(); break;
        case 13: _t->slotPaste(); break;
        case 14: _t->slotCut(); break;
        case 15: _t->slotSaveAs(); break;
        case 16: _t->slotCheckSpelling(); break;
        case 17: _t->slotImport(); break;
        case 18: _t->slotCreateRulesGraphically(); break;
        case 19: _t->slotCheckSyntax(); break;
        case 20: _t->slotComment(); break;
        case 21: _t->slotUncomment(); break;
        case 22: _t->slotUpperCase(); break;
        case 23: _t->slotSentenceCase(); break;
        case 24: _t->slotLowerCase(); break;
        case 25: _t->slotReverseCase(); break;
        case 26: _t->slotZoomIn(); break;
        case 27: _t->slotZoomOut(); break;
        case 28: _t->slotZoomReset(); break;
        case 29: _t->slotWordWrap((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->slotPrintPreview(); break;
        case 31: _t->slotPrint(); break;
        case 32: _t->slotUndo(); break;
        case 33: _t->slotRedo(); break;
        case 34: _t->slotSelectAll(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMainWidget::*)(bool , bool , bool , bool )>(_a, &SieveEditorMainWidget::updateButtons, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMainWidget::*)()>(_a, &SieveEditorMainWidget::updateScriptList, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMainWidget::*)(KSieveUi::SieveEditorWidget::EditorMode )>(_a, &SieveEditorMainWidget::modeEditorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMainWidget::*)(bool )>(_a, &SieveEditorMainWidget::serverSieveFound, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMainWidget::*)(bool )>(_a, &SieveEditorMainWidget::undoAvailable, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMainWidget::*)(bool )>(_a, &SieveEditorMainWidget::redoAvailable, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMainWidget::*)(bool )>(_a, &SieveEditorMainWidget::copyAvailable, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SieveEditorMainWidget::*)()>(_a, &SieveEditorMainWidget::sieveEditorTabCurrentChanged, 7))
            return;
    }
}

const QMetaObject *SieveEditorMainWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SieveEditorMainWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SieveEditorMainWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QSplitter::qt_metacast(_clname);
}

int SieveEditorMainWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSplitter::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void SieveEditorMainWidget::updateButtons(bool _t1, bool _t2, bool _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void SieveEditorMainWidget::updateScriptList()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SieveEditorMainWidget::modeEditorChanged(KSieveUi::SieveEditorWidget::EditorMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SieveEditorMainWidget::serverSieveFound(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SieveEditorMainWidget::undoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void SieveEditorMainWidget::redoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void SieveEditorMainWidget::copyAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void SieveEditorMainWidget::sieveEditorTabCurrentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
