/********************************************************************************
** Form generated from reading UI file 'sieveeditorconfigureserverwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SIEVEEDITORCONFIGURESERVERWIDGET_H
#define UI_SIEVEEDITORCONFIGURESERVERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "serversievelistwidget.h"

QT_BEGIN_NAMESPACE

class Ui_SieveEditorConfigureServerWidget
{
public:
    QGridLayout *gridLayout;
    ServerSieveListWidget *serverSieveListWidget;
    QVBoxLayout *verticalLayout;
    QPushButton *addServer;
    QPushButton *modifyServer;
    QPushButton *removeServer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SieveEditorConfigureServerWidget)
    {
        if (SieveEditorConfigureServerWidget->objectName().isEmpty())
            SieveEditorConfigureServerWidget->setObjectName("SieveEditorConfigureServerWidget");
        SieveEditorConfigureServerWidget->resize(400, 300);
        gridLayout = new QGridLayout(SieveEditorConfigureServerWidget);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        serverSieveListWidget = new ServerSieveListWidget(SieveEditorConfigureServerWidget);
        serverSieveListWidget->setObjectName("serverSieveListWidget");

        gridLayout->addWidget(serverSieveListWidget, 0, 0, 2, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        addServer = new QPushButton(SieveEditorConfigureServerWidget);
        addServer->setObjectName("addServer");

        verticalLayout->addWidget(addServer);

        modifyServer = new QPushButton(SieveEditorConfigureServerWidget);
        modifyServer->setObjectName("modifyServer");

        verticalLayout->addWidget(modifyServer);

        removeServer = new QPushButton(SieveEditorConfigureServerWidget);
        removeServer->setObjectName("removeServer");

        verticalLayout->addWidget(removeServer);


        gridLayout->addLayout(verticalLayout, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 193, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 1, 1, 1);


        retranslateUi(SieveEditorConfigureServerWidget);

        QMetaObject::connectSlotsByName(SieveEditorConfigureServerWidget);
    } // setupUi

    void retranslateUi(QWidget *SieveEditorConfigureServerWidget)
    {
        addServer->setText(tr2i18n("Add\342\200\246", nullptr));
        modifyServer->setText(tr2i18n("Modify\342\200\246", nullptr));
        removeServer->setText(tr2i18n("Remove", nullptr));
        (void)SieveEditorConfigureServerWidget;
    } // retranslateUi

};

namespace Ui {
    class SieveEditorConfigureServerWidget: public Ui_SieveEditorConfigureServerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SIEVEEDITORCONFIGURESERVERWIDGET_H

